Documentation
¶
Index ¶
- Variables
- type AssociateUserNodeRequest
- func (*AssociateUserNodeRequest) Descriptor() ([]byte, []int)deprecated
- func (x *AssociateUserNodeRequest) GetNodeId() string
- func (*AssociateUserNodeRequest) ProtoMessage()
- func (x *AssociateUserNodeRequest) ProtoReflect() protoreflect.Message
- func (x *AssociateUserNodeRequest) Reset()
- func (x *AssociateUserNodeRequest) String() string
- type AssociateUserNodeResponse
- func (*AssociateUserNodeResponse) Descriptor() ([]byte, []int)deprecated
- func (x *AssociateUserNodeResponse) GetSuccess() bool
- func (*AssociateUserNodeResponse) ProtoMessage()
- func (x *AssociateUserNodeResponse) ProtoReflect() protoreflect.Message
- func (x *AssociateUserNodeResponse) Reset()
- func (x *AssociateUserNodeResponse) String() string
- type CountEventsForUserRequest
- type CountEventsForUserResponse
- func (*CountEventsForUserResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CountEventsForUserResponse) GetCount() int64
- func (*CountEventsForUserResponse) ProtoMessage()
- func (x *CountEventsForUserResponse) ProtoReflect() protoreflect.Message
- func (x *CountEventsForUserResponse) Reset()
- func (x *CountEventsForUserResponse) String() string
- type CreateServiceRequest
- func (*CreateServiceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateServiceRequest) GetName() string
- func (x *CreateServiceRequest) GetNodeId() string
- func (x *CreateServiceRequest) GetUrl() string
- func (*CreateServiceRequest) ProtoMessage()
- func (x *CreateServiceRequest) ProtoReflect() protoreflect.Message
- func (x *CreateServiceRequest) Reset()
- func (x *CreateServiceRequest) String() string
- type CreateServiceResponse
- func (*CreateServiceResponse) Descriptor() ([]byte, []int)deprecated
- func (x *CreateServiceResponse) GetService() *Service
- func (*CreateServiceResponse) ProtoMessage()
- func (x *CreateServiceResponse) ProtoReflect() protoreflect.Message
- func (x *CreateServiceResponse) Reset()
- func (x *CreateServiceResponse) String() string
- type DeleteOldStorageItemsRequest
- func (*DeleteOldStorageItemsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteOldStorageItemsRequest) GetOlderThanSeconds() int64
- func (x *DeleteOldStorageItemsRequest) GetServiceId() string
- func (x *DeleteOldStorageItemsRequest) GetType() string
- func (*DeleteOldStorageItemsRequest) ProtoMessage()
- func (x *DeleteOldStorageItemsRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteOldStorageItemsRequest) Reset()
- func (x *DeleteOldStorageItemsRequest) String() string
- type DeleteOldStorageItemsResponse
- func (*DeleteOldStorageItemsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteOldStorageItemsResponse) GetDeletedCount() int64
- func (*DeleteOldStorageItemsResponse) ProtoMessage()
- func (x *DeleteOldStorageItemsResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteOldStorageItemsResponse) Reset()
- func (x *DeleteOldStorageItemsResponse) String() string
- type DeleteServiceRequest
- func (*DeleteServiceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteServiceRequest) GetServiceId() string
- func (*DeleteServiceRequest) ProtoMessage()
- func (x *DeleteServiceRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteServiceRequest) Reset()
- func (x *DeleteServiceRequest) String() string
- type DeleteServiceResponse
- func (*DeleteServiceResponse) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteServiceResponse) GetSuccess() bool
- func (*DeleteServiceResponse) ProtoMessage()
- func (x *DeleteServiceResponse) ProtoReflect() protoreflect.Message
- func (x *DeleteServiceResponse) Reset()
- func (x *DeleteServiceResponse) String() string
- type Event
- func (*Event) Descriptor() ([]byte, []int)deprecated
- func (x *Event) GetCreatedAt() *timestamppb.Timestamp
- func (x *Event) GetId() string
- func (x *Event) GetPayload() *structpb.Struct
- func (x *Event) GetServiceId() string
- func (*Event) ProtoMessage()
- func (x *Event) ProtoReflect() protoreflect.Message
- func (x *Event) Reset()
- func (x *Event) String() string
- type GetStorageItemRequest
- func (*GetStorageItemRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetStorageItemRequest) GetItemId() string
- func (*GetStorageItemRequest) ProtoMessage()
- func (x *GetStorageItemRequest) ProtoReflect() protoreflect.Message
- func (x *GetStorageItemRequest) Reset()
- func (x *GetStorageItemRequest) String() string
- type GetStorageItemResponse
- func (*GetStorageItemResponse) Descriptor() ([]byte, []int)deprecated
- func (x *GetStorageItemResponse) GetItem() *StorageItem
- func (*GetStorageItemResponse) ProtoMessage()
- func (x *GetStorageItemResponse) ProtoReflect() protoreflect.Message
- func (x *GetStorageItemResponse) Reset()
- func (x *GetStorageItemResponse) String() string
- type ListEventsByNodeIdRequest
- func (*ListEventsByNodeIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListEventsByNodeIdRequest) GetNodeId() string
- func (x *ListEventsByNodeIdRequest) GetPageOffset() int32
- func (x *ListEventsByNodeIdRequest) GetPageSize() int32
- func (*ListEventsByNodeIdRequest) ProtoMessage()
- func (x *ListEventsByNodeIdRequest) ProtoReflect() protoreflect.Message
- func (x *ListEventsByNodeIdRequest) Reset()
- func (x *ListEventsByNodeIdRequest) String() string
- type ListEventsByNodeIdResponse
- func (*ListEventsByNodeIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListEventsByNodeIdResponse) GetEvents() []*Event
- func (x *ListEventsByNodeIdResponse) GetTotalCount() int32
- func (*ListEventsByNodeIdResponse) ProtoMessage()
- func (x *ListEventsByNodeIdResponse) ProtoReflect() protoreflect.Message
- func (x *ListEventsByNodeIdResponse) Reset()
- func (x *ListEventsByNodeIdResponse) String() string
- type ListServicesByNodeIdRequest
- func (*ListServicesByNodeIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListServicesByNodeIdRequest) GetNodeId() string
- func (*ListServicesByNodeIdRequest) ProtoMessage()
- func (x *ListServicesByNodeIdRequest) ProtoReflect() protoreflect.Message
- func (x *ListServicesByNodeIdRequest) Reset()
- func (x *ListServicesByNodeIdRequest) String() string
- type ListServicesByNodeIdResponse
- func (*ListServicesByNodeIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListServicesByNodeIdResponse) GetNodeOnline() bool
- func (x *ListServicesByNodeIdResponse) GetServices() []*Service
- func (*ListServicesByNodeIdResponse) ProtoMessage()
- func (x *ListServicesByNodeIdResponse) ProtoReflect() protoreflect.Message
- func (x *ListServicesByNodeIdResponse) Reset()
- func (x *ListServicesByNodeIdResponse) String() string
- type ListStorageItemsRequest
- func (*ListStorageItemsRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ListStorageItemsRequest) GetLimit() int64
- func (x *ListStorageItemsRequest) GetOffset() int64
- func (x *ListStorageItemsRequest) GetServiceId() string
- func (x *ListStorageItemsRequest) GetType() string
- func (*ListStorageItemsRequest) ProtoMessage()
- func (x *ListStorageItemsRequest) ProtoReflect() protoreflect.Message
- func (x *ListStorageItemsRequest) Reset()
- func (x *ListStorageItemsRequest) String() string
- type ListStorageItemsResponse
- func (*ListStorageItemsResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListStorageItemsResponse) GetItems() []*StorageItem
- func (x *ListStorageItemsResponse) GetTotal() int64
- func (*ListStorageItemsResponse) ProtoMessage()
- func (x *ListStorageItemsResponse) ProtoReflect() protoreflect.Message
- func (x *ListStorageItemsResponse) Reset()
- func (x *ListStorageItemsResponse) String() string
- type ListUserNodesRequest
- type ListUserNodesResponse
- func (*ListUserNodesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ListUserNodesResponse) GetNodeIds() []string
- func (*ListUserNodesResponse) ProtoMessage()
- func (x *ListUserNodesResponse) ProtoReflect() protoreflect.Message
- func (x *ListUserNodesResponse) Reset()
- func (x *ListUserNodesResponse) String() string
- type NodeStatusChanged
- func (*NodeStatusChanged) Descriptor() ([]byte, []int)deprecated
- func (x *NodeStatusChanged) GetNodeId() string
- func (x *NodeStatusChanged) GetOnline() bool
- func (*NodeStatusChanged) ProtoMessage()
- func (x *NodeStatusChanged) ProtoReflect() protoreflect.Message
- func (x *NodeStatusChanged) Reset()
- func (x *NodeStatusChanged) String() string
- type Notification
- func (*Notification) Descriptor() ([]byte, []int)deprecated
- func (x *Notification) GetBody() string
- func (x *Notification) GetId() string
- func (x *Notification) GetTitle() string
- func (*Notification) ProtoMessage()
- func (x *Notification) ProtoReflect() protoreflect.Message
- func (x *Notification) Reset()
- func (x *Notification) String() string
- type Service
- func (*Service) Descriptor() ([]byte, []int)deprecated
- func (x *Service) GetCreatedAt() *timestamppb.Timestamp
- func (x *Service) GetId() string
- func (x *Service) GetName() string
- func (x *Service) GetNodeId() string
- func (x *Service) GetUpdatedAt() *timestamppb.Timestamp
- func (x *Service) GetUrl() string
- func (*Service) ProtoMessage()
- func (x *Service) ProtoReflect() protoreflect.Message
- func (x *Service) Reset()
- func (x *Service) String() string
- type StorageItem
- func (*StorageItem) Descriptor() ([]byte, []int)deprecated
- func (x *StorageItem) GetId() string
- func (x *StorageItem) GetMetadata() string
- func (x *StorageItem) GetServiceId() string
- func (x *StorageItem) GetSize() int64
- func (x *StorageItem) GetTimestamp() *timestamppb.Timestamp
- func (x *StorageItem) GetType() string
- func (*StorageItem) ProtoMessage()
- func (x *StorageItem) ProtoReflect() protoreflect.Message
- func (x *StorageItem) Reset()
- func (x *StorageItem) String() string
- type StreamEventsByNodeIdRequest
- func (*StreamEventsByNodeIdRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StreamEventsByNodeIdRequest) GetNodeId() string
- func (x *StreamEventsByNodeIdRequest) GetServiceId() string
- func (x *StreamEventsByNodeIdRequest) GetSinceTimestamp() int64
- func (*StreamEventsByNodeIdRequest) ProtoMessage()
- func (x *StreamEventsByNodeIdRequest) ProtoReflect() protoreflect.Message
- func (x *StreamEventsByNodeIdRequest) Reset()
- func (x *StreamEventsByNodeIdRequest) String() string
- type StreamEventsByNodeIdResponse
- func (*StreamEventsByNodeIdResponse) Descriptor() ([]byte, []int)deprecated
- func (x *StreamEventsByNodeIdResponse) GetEvent() *Event
- func (x *StreamEventsByNodeIdResponse) GetHeartbeat() string
- func (x *StreamEventsByNodeIdResponse) GetPayload() isStreamEventsByNodeIdResponse_Payload
- func (*StreamEventsByNodeIdResponse) ProtoMessage()
- func (x *StreamEventsByNodeIdResponse) ProtoReflect() protoreflect.Message
- func (x *StreamEventsByNodeIdResponse) Reset()
- func (x *StreamEventsByNodeIdResponse) String() string
- type StreamEventsByNodeIdResponse_Event
- type StreamEventsByNodeIdResponse_Heartbeat
- type StreamLiveUpdatesRequest
- func (*StreamLiveUpdatesRequest) Descriptor() ([]byte, []int)deprecated
- func (x *StreamLiveUpdatesRequest) GetNodeIds() []string
- func (*StreamLiveUpdatesRequest) ProtoMessage()
- func (x *StreamLiveUpdatesRequest) ProtoReflect() protoreflect.Message
- func (x *StreamLiveUpdatesRequest) Reset()
- func (x *StreamLiveUpdatesRequest) String() string
- type StreamLiveUpdatesResponse
- func (*StreamLiveUpdatesResponse) Descriptor() ([]byte, []int)deprecated
- func (x *StreamLiveUpdatesResponse) GetHeartbeat() string
- func (x *StreamLiveUpdatesResponse) GetNodeStatusChanged() *NodeStatusChanged
- func (x *StreamLiveUpdatesResponse) GetNotification() *Notification
- func (x *StreamLiveUpdatesResponse) GetPayload() isStreamLiveUpdatesResponse_Payload
- func (*StreamLiveUpdatesResponse) ProtoMessage()
- func (x *StreamLiveUpdatesResponse) ProtoReflect() protoreflect.Message
- func (x *StreamLiveUpdatesResponse) Reset()
- func (x *StreamLiveUpdatesResponse) String() string
- type StreamLiveUpdatesResponse_Heartbeat
- type StreamLiveUpdatesResponse_NodeStatusChanged
- type StreamLiveUpdatesResponse_Notification
- type UpdateServiceRequest
- func (*UpdateServiceRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateServiceRequest) GetId() string
- func (x *UpdateServiceRequest) GetName() string
- func (x *UpdateServiceRequest) GetUrl() string
- func (*UpdateServiceRequest) ProtoMessage()
- func (x *UpdateServiceRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateServiceRequest) Reset()
- func (x *UpdateServiceRequest) String() string
- type UpdateServiceResponse
- func (*UpdateServiceResponse) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateServiceResponse) GetService() *Service
- func (*UpdateServiceResponse) ProtoMessage()
- func (x *UpdateServiceResponse) ProtoReflect() protoreflect.Message
- func (x *UpdateServiceResponse) Reset()
- func (x *UpdateServiceResponse) String() string
Constants ¶
This section is empty.
Variables ¶
var File_service_v1_event_proto protoreflect.FileDescriptor
var File_service_v1_live_update_proto protoreflect.FileDescriptor
var File_service_v1_service_proto protoreflect.FileDescriptor
var File_service_v1_storage_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type AssociateUserNodeRequest ¶
type AssociateUserNodeRequest struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
// contains filtered or unexported fields
}
func (*AssociateUserNodeRequest) Descriptor
deprecated
func (*AssociateUserNodeRequest) Descriptor() ([]byte, []int)
Deprecated: Use AssociateUserNodeRequest.ProtoReflect.Descriptor instead.
func (*AssociateUserNodeRequest) GetNodeId ¶
func (x *AssociateUserNodeRequest) GetNodeId() string
func (*AssociateUserNodeRequest) ProtoMessage ¶
func (*AssociateUserNodeRequest) ProtoMessage()
func (*AssociateUserNodeRequest) ProtoReflect ¶
func (x *AssociateUserNodeRequest) ProtoReflect() protoreflect.Message
func (*AssociateUserNodeRequest) Reset ¶
func (x *AssociateUserNodeRequest) Reset()
func (*AssociateUserNodeRequest) String ¶
func (x *AssociateUserNodeRequest) String() string
type AssociateUserNodeResponse ¶
type AssociateUserNodeResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
func (*AssociateUserNodeResponse) Descriptor
deprecated
func (*AssociateUserNodeResponse) Descriptor() ([]byte, []int)
Deprecated: Use AssociateUserNodeResponse.ProtoReflect.Descriptor instead.
func (*AssociateUserNodeResponse) GetSuccess ¶
func (x *AssociateUserNodeResponse) GetSuccess() bool
func (*AssociateUserNodeResponse) ProtoMessage ¶
func (*AssociateUserNodeResponse) ProtoMessage()
func (*AssociateUserNodeResponse) ProtoReflect ¶
func (x *AssociateUserNodeResponse) ProtoReflect() protoreflect.Message
func (*AssociateUserNodeResponse) Reset ¶
func (x *AssociateUserNodeResponse) Reset()
func (*AssociateUserNodeResponse) String ¶
func (x *AssociateUserNodeResponse) String() string
type CountEventsForUserRequest ¶
type CountEventsForUserRequest struct {
// contains filtered or unexported fields
}
func (*CountEventsForUserRequest) Descriptor
deprecated
func (*CountEventsForUserRequest) Descriptor() ([]byte, []int)
Deprecated: Use CountEventsForUserRequest.ProtoReflect.Descriptor instead.
func (*CountEventsForUserRequest) ProtoMessage ¶
func (*CountEventsForUserRequest) ProtoMessage()
func (*CountEventsForUserRequest) ProtoReflect ¶
func (x *CountEventsForUserRequest) ProtoReflect() protoreflect.Message
func (*CountEventsForUserRequest) Reset ¶
func (x *CountEventsForUserRequest) Reset()
func (*CountEventsForUserRequest) String ¶
func (x *CountEventsForUserRequest) String() string
type CountEventsForUserResponse ¶
type CountEventsForUserResponse struct {
Count int64 `protobuf:"varint,1,opt,name=count,proto3" json:"count,omitempty"`
// contains filtered or unexported fields
}
func (*CountEventsForUserResponse) Descriptor
deprecated
func (*CountEventsForUserResponse) Descriptor() ([]byte, []int)
Deprecated: Use CountEventsForUserResponse.ProtoReflect.Descriptor instead.
func (*CountEventsForUserResponse) GetCount ¶
func (x *CountEventsForUserResponse) GetCount() int64
func (*CountEventsForUserResponse) ProtoMessage ¶
func (*CountEventsForUserResponse) ProtoMessage()
func (*CountEventsForUserResponse) ProtoReflect ¶
func (x *CountEventsForUserResponse) ProtoReflect() protoreflect.Message
func (*CountEventsForUserResponse) Reset ¶
func (x *CountEventsForUserResponse) Reset()
func (*CountEventsForUserResponse) String ¶
func (x *CountEventsForUserResponse) String() string
type CreateServiceRequest ¶
type CreateServiceRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Url string `protobuf:"bytes,2,opt,name=url,proto3" json:"url,omitempty"`
NodeId string `protobuf:"bytes,3,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
// contains filtered or unexported fields
}
func (*CreateServiceRequest) Descriptor
deprecated
func (*CreateServiceRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateServiceRequest.ProtoReflect.Descriptor instead.
func (*CreateServiceRequest) GetName ¶
func (x *CreateServiceRequest) GetName() string
func (*CreateServiceRequest) GetNodeId ¶
func (x *CreateServiceRequest) GetNodeId() string
func (*CreateServiceRequest) GetUrl ¶
func (x *CreateServiceRequest) GetUrl() string
func (*CreateServiceRequest) ProtoMessage ¶
func (*CreateServiceRequest) ProtoMessage()
func (*CreateServiceRequest) ProtoReflect ¶
func (x *CreateServiceRequest) ProtoReflect() protoreflect.Message
func (*CreateServiceRequest) Reset ¶
func (x *CreateServiceRequest) Reset()
func (*CreateServiceRequest) String ¶
func (x *CreateServiceRequest) String() string
type CreateServiceResponse ¶
type CreateServiceResponse struct {
Service *Service `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
// contains filtered or unexported fields
}
func (*CreateServiceResponse) Descriptor
deprecated
func (*CreateServiceResponse) Descriptor() ([]byte, []int)
Deprecated: Use CreateServiceResponse.ProtoReflect.Descriptor instead.
func (*CreateServiceResponse) GetService ¶
func (x *CreateServiceResponse) GetService() *Service
func (*CreateServiceResponse) ProtoMessage ¶
func (*CreateServiceResponse) ProtoMessage()
func (*CreateServiceResponse) ProtoReflect ¶
func (x *CreateServiceResponse) ProtoReflect() protoreflect.Message
func (*CreateServiceResponse) Reset ¶
func (x *CreateServiceResponse) Reset()
func (*CreateServiceResponse) String ¶
func (x *CreateServiceResponse) String() string
type DeleteOldStorageItemsRequest ¶
type DeleteOldStorageItemsRequest struct {
ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
OlderThanSeconds int64 `protobuf:"varint,2,opt,name=older_than_seconds,json=olderThanSeconds,proto3" json:"older_than_seconds,omitempty"` // Delete items older than this many seconds
Type string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"` // Optional filter by type (empty = all types)
// contains filtered or unexported fields
}
Delete old storage items
func (*DeleteOldStorageItemsRequest) Descriptor
deprecated
func (*DeleteOldStorageItemsRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteOldStorageItemsRequest.ProtoReflect.Descriptor instead.
func (*DeleteOldStorageItemsRequest) GetOlderThanSeconds ¶
func (x *DeleteOldStorageItemsRequest) GetOlderThanSeconds() int64
func (*DeleteOldStorageItemsRequest) GetServiceId ¶
func (x *DeleteOldStorageItemsRequest) GetServiceId() string
func (*DeleteOldStorageItemsRequest) GetType ¶
func (x *DeleteOldStorageItemsRequest) GetType() string
func (*DeleteOldStorageItemsRequest) ProtoMessage ¶
func (*DeleteOldStorageItemsRequest) ProtoMessage()
func (*DeleteOldStorageItemsRequest) ProtoReflect ¶
func (x *DeleteOldStorageItemsRequest) ProtoReflect() protoreflect.Message
func (*DeleteOldStorageItemsRequest) Reset ¶
func (x *DeleteOldStorageItemsRequest) Reset()
func (*DeleteOldStorageItemsRequest) String ¶
func (x *DeleteOldStorageItemsRequest) String() string
type DeleteOldStorageItemsResponse ¶
type DeleteOldStorageItemsResponse struct {
DeletedCount int64 `protobuf:"varint,1,opt,name=deleted_count,json=deletedCount,proto3" json:"deleted_count,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteOldStorageItemsResponse) Descriptor
deprecated
func (*DeleteOldStorageItemsResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteOldStorageItemsResponse.ProtoReflect.Descriptor instead.
func (*DeleteOldStorageItemsResponse) GetDeletedCount ¶
func (x *DeleteOldStorageItemsResponse) GetDeletedCount() int64
func (*DeleteOldStorageItemsResponse) ProtoMessage ¶
func (*DeleteOldStorageItemsResponse) ProtoMessage()
func (*DeleteOldStorageItemsResponse) ProtoReflect ¶
func (x *DeleteOldStorageItemsResponse) ProtoReflect() protoreflect.Message
func (*DeleteOldStorageItemsResponse) Reset ¶
func (x *DeleteOldStorageItemsResponse) Reset()
func (*DeleteOldStorageItemsResponse) String ¶
func (x *DeleteOldStorageItemsResponse) String() string
type DeleteServiceRequest ¶
type DeleteServiceRequest struct {
ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteServiceRequest) Descriptor
deprecated
func (*DeleteServiceRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteServiceRequest.ProtoReflect.Descriptor instead.
func (*DeleteServiceRequest) GetServiceId ¶
func (x *DeleteServiceRequest) GetServiceId() string
func (*DeleteServiceRequest) ProtoMessage ¶
func (*DeleteServiceRequest) ProtoMessage()
func (*DeleteServiceRequest) ProtoReflect ¶
func (x *DeleteServiceRequest) ProtoReflect() protoreflect.Message
func (*DeleteServiceRequest) Reset ¶
func (x *DeleteServiceRequest) Reset()
func (*DeleteServiceRequest) String ¶
func (x *DeleteServiceRequest) String() string
type DeleteServiceResponse ¶
type DeleteServiceResponse struct {
Success bool `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
// contains filtered or unexported fields
}
func (*DeleteServiceResponse) Descriptor
deprecated
func (*DeleteServiceResponse) Descriptor() ([]byte, []int)
Deprecated: Use DeleteServiceResponse.ProtoReflect.Descriptor instead.
func (*DeleteServiceResponse) GetSuccess ¶
func (x *DeleteServiceResponse) GetSuccess() bool
func (*DeleteServiceResponse) ProtoMessage ¶
func (*DeleteServiceResponse) ProtoMessage()
func (*DeleteServiceResponse) ProtoReflect ¶
func (x *DeleteServiceResponse) ProtoReflect() protoreflect.Message
func (*DeleteServiceResponse) Reset ¶
func (x *DeleteServiceResponse) Reset()
func (*DeleteServiceResponse) String ¶
func (x *DeleteServiceResponse) String() string
type Event ¶
type Event struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
ServiceId string `protobuf:"bytes,2,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
Payload *structpb.Struct `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
// contains filtered or unexported fields
}
func (*Event) Descriptor
deprecated
func (*Event) GetCreatedAt ¶
func (x *Event) GetCreatedAt() *timestamppb.Timestamp
func (*Event) GetPayload ¶
func (*Event) GetServiceId ¶
func (*Event) ProtoMessage ¶
func (*Event) ProtoMessage()
func (*Event) ProtoReflect ¶
func (x *Event) ProtoReflect() protoreflect.Message
type GetStorageItemRequest ¶
type GetStorageItemRequest struct {
ItemId string `protobuf:"bytes,1,opt,name=item_id,json=itemId,proto3" json:"item_id,omitempty"`
// contains filtered or unexported fields
}
Get storage item metadata
func (*GetStorageItemRequest) Descriptor
deprecated
func (*GetStorageItemRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetStorageItemRequest.ProtoReflect.Descriptor instead.
func (*GetStorageItemRequest) GetItemId ¶
func (x *GetStorageItemRequest) GetItemId() string
func (*GetStorageItemRequest) ProtoMessage ¶
func (*GetStorageItemRequest) ProtoMessage()
func (*GetStorageItemRequest) ProtoReflect ¶
func (x *GetStorageItemRequest) ProtoReflect() protoreflect.Message
func (*GetStorageItemRequest) Reset ¶
func (x *GetStorageItemRequest) Reset()
func (*GetStorageItemRequest) String ¶
func (x *GetStorageItemRequest) String() string
type GetStorageItemResponse ¶
type GetStorageItemResponse struct {
Item *StorageItem `protobuf:"bytes,1,opt,name=item,proto3" json:"item,omitempty"`
// contains filtered or unexported fields
}
func (*GetStorageItemResponse) Descriptor
deprecated
func (*GetStorageItemResponse) Descriptor() ([]byte, []int)
Deprecated: Use GetStorageItemResponse.ProtoReflect.Descriptor instead.
func (*GetStorageItemResponse) GetItem ¶
func (x *GetStorageItemResponse) GetItem() *StorageItem
func (*GetStorageItemResponse) ProtoMessage ¶
func (*GetStorageItemResponse) ProtoMessage()
func (*GetStorageItemResponse) ProtoReflect ¶
func (x *GetStorageItemResponse) ProtoReflect() protoreflect.Message
func (*GetStorageItemResponse) Reset ¶
func (x *GetStorageItemResponse) Reset()
func (*GetStorageItemResponse) String ¶
func (x *GetStorageItemResponse) String() string
type ListEventsByNodeIdRequest ¶
type ListEventsByNodeIdRequest struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"` // Number of events per page (default 20, max 100)
PageOffset int32 `protobuf:"varint,3,opt,name=page_offset,json=pageOffset,proto3" json:"page_offset,omitempty"` // Offset for pagination (0-based)
// contains filtered or unexported fields
}
func (*ListEventsByNodeIdRequest) Descriptor
deprecated
func (*ListEventsByNodeIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListEventsByNodeIdRequest.ProtoReflect.Descriptor instead.
func (*ListEventsByNodeIdRequest) GetNodeId ¶
func (x *ListEventsByNodeIdRequest) GetNodeId() string
func (*ListEventsByNodeIdRequest) GetPageOffset ¶
func (x *ListEventsByNodeIdRequest) GetPageOffset() int32
func (*ListEventsByNodeIdRequest) GetPageSize ¶
func (x *ListEventsByNodeIdRequest) GetPageSize() int32
func (*ListEventsByNodeIdRequest) ProtoMessage ¶
func (*ListEventsByNodeIdRequest) ProtoMessage()
func (*ListEventsByNodeIdRequest) ProtoReflect ¶
func (x *ListEventsByNodeIdRequest) ProtoReflect() protoreflect.Message
func (*ListEventsByNodeIdRequest) Reset ¶
func (x *ListEventsByNodeIdRequest) Reset()
func (*ListEventsByNodeIdRequest) String ¶
func (x *ListEventsByNodeIdRequest) String() string
type ListEventsByNodeIdResponse ¶
type ListEventsByNodeIdResponse struct {
Events []*Event `protobuf:"bytes,1,rep,name=events,proto3" json:"events,omitempty"`
TotalCount int32 `protobuf:"varint,2,opt,name=total_count,json=totalCount,proto3" json:"total_count,omitempty"` // Total number of events (for client-side pagination UI)
// contains filtered or unexported fields
}
func (*ListEventsByNodeIdResponse) Descriptor
deprecated
func (*ListEventsByNodeIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListEventsByNodeIdResponse.ProtoReflect.Descriptor instead.
func (*ListEventsByNodeIdResponse) GetEvents ¶
func (x *ListEventsByNodeIdResponse) GetEvents() []*Event
func (*ListEventsByNodeIdResponse) GetTotalCount ¶
func (x *ListEventsByNodeIdResponse) GetTotalCount() int32
func (*ListEventsByNodeIdResponse) ProtoMessage ¶
func (*ListEventsByNodeIdResponse) ProtoMessage()
func (*ListEventsByNodeIdResponse) ProtoReflect ¶
func (x *ListEventsByNodeIdResponse) ProtoReflect() protoreflect.Message
func (*ListEventsByNodeIdResponse) Reset ¶
func (x *ListEventsByNodeIdResponse) Reset()
func (*ListEventsByNodeIdResponse) String ¶
func (x *ListEventsByNodeIdResponse) String() string
type ListServicesByNodeIdRequest ¶
type ListServicesByNodeIdRequest struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
// contains filtered or unexported fields
}
func (*ListServicesByNodeIdRequest) Descriptor
deprecated
func (*ListServicesByNodeIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListServicesByNodeIdRequest.ProtoReflect.Descriptor instead.
func (*ListServicesByNodeIdRequest) GetNodeId ¶
func (x *ListServicesByNodeIdRequest) GetNodeId() string
func (*ListServicesByNodeIdRequest) ProtoMessage ¶
func (*ListServicesByNodeIdRequest) ProtoMessage()
func (*ListServicesByNodeIdRequest) ProtoReflect ¶
func (x *ListServicesByNodeIdRequest) ProtoReflect() protoreflect.Message
func (*ListServicesByNodeIdRequest) Reset ¶
func (x *ListServicesByNodeIdRequest) Reset()
func (*ListServicesByNodeIdRequest) String ¶
func (x *ListServicesByNodeIdRequest) String() string
type ListServicesByNodeIdResponse ¶
type ListServicesByNodeIdResponse struct {
Services []*Service `protobuf:"bytes,1,rep,name=services,proto3" json:"services,omitempty"`
NodeOnline bool `protobuf:"varint,2,opt,name=node_online,json=nodeOnline,proto3" json:"node_online,omitempty"`
// contains filtered or unexported fields
}
func (*ListServicesByNodeIdResponse) Descriptor
deprecated
func (*ListServicesByNodeIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListServicesByNodeIdResponse.ProtoReflect.Descriptor instead.
func (*ListServicesByNodeIdResponse) GetNodeOnline ¶
func (x *ListServicesByNodeIdResponse) GetNodeOnline() bool
func (*ListServicesByNodeIdResponse) GetServices ¶
func (x *ListServicesByNodeIdResponse) GetServices() []*Service
func (*ListServicesByNodeIdResponse) ProtoMessage ¶
func (*ListServicesByNodeIdResponse) ProtoMessage()
func (*ListServicesByNodeIdResponse) ProtoReflect ¶
func (x *ListServicesByNodeIdResponse) ProtoReflect() protoreflect.Message
func (*ListServicesByNodeIdResponse) Reset ¶
func (x *ListServicesByNodeIdResponse) Reset()
func (*ListServicesByNodeIdResponse) String ¶
func (x *ListServicesByNodeIdResponse) String() string
type ListStorageItemsRequest ¶
type ListStorageItemsRequest struct {
ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"` // Optional filter by type (empty = all types)
Limit int64 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"` // Max items to return (default 100)
Offset int64 `protobuf:"varint,4,opt,name=offset,proto3" json:"offset,omitempty"` // For pagination
// contains filtered or unexported fields
}
List storage items for a service
func (*ListStorageItemsRequest) Descriptor
deprecated
func (*ListStorageItemsRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListStorageItemsRequest.ProtoReflect.Descriptor instead.
func (*ListStorageItemsRequest) GetLimit ¶
func (x *ListStorageItemsRequest) GetLimit() int64
func (*ListStorageItemsRequest) GetOffset ¶
func (x *ListStorageItemsRequest) GetOffset() int64
func (*ListStorageItemsRequest) GetServiceId ¶
func (x *ListStorageItemsRequest) GetServiceId() string
func (*ListStorageItemsRequest) GetType ¶
func (x *ListStorageItemsRequest) GetType() string
func (*ListStorageItemsRequest) ProtoMessage ¶
func (*ListStorageItemsRequest) ProtoMessage()
func (*ListStorageItemsRequest) ProtoReflect ¶
func (x *ListStorageItemsRequest) ProtoReflect() protoreflect.Message
func (*ListStorageItemsRequest) Reset ¶
func (x *ListStorageItemsRequest) Reset()
func (*ListStorageItemsRequest) String ¶
func (x *ListStorageItemsRequest) String() string
type ListStorageItemsResponse ¶
type ListStorageItemsResponse struct {
Items []*StorageItem `protobuf:"bytes,1,rep,name=items,proto3" json:"items,omitempty"`
Total int64 `protobuf:"varint,2,opt,name=total,proto3" json:"total,omitempty"`
// contains filtered or unexported fields
}
func (*ListStorageItemsResponse) Descriptor
deprecated
func (*ListStorageItemsResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListStorageItemsResponse.ProtoReflect.Descriptor instead.
func (*ListStorageItemsResponse) GetItems ¶
func (x *ListStorageItemsResponse) GetItems() []*StorageItem
func (*ListStorageItemsResponse) GetTotal ¶
func (x *ListStorageItemsResponse) GetTotal() int64
func (*ListStorageItemsResponse) ProtoMessage ¶
func (*ListStorageItemsResponse) ProtoMessage()
func (*ListStorageItemsResponse) ProtoReflect ¶
func (x *ListStorageItemsResponse) ProtoReflect() protoreflect.Message
func (*ListStorageItemsResponse) Reset ¶
func (x *ListStorageItemsResponse) Reset()
func (*ListStorageItemsResponse) String ¶
func (x *ListStorageItemsResponse) String() string
type ListUserNodesRequest ¶
type ListUserNodesRequest struct {
// contains filtered or unexported fields
}
func (*ListUserNodesRequest) Descriptor
deprecated
func (*ListUserNodesRequest) Descriptor() ([]byte, []int)
Deprecated: Use ListUserNodesRequest.ProtoReflect.Descriptor instead.
func (*ListUserNodesRequest) ProtoMessage ¶
func (*ListUserNodesRequest) ProtoMessage()
func (*ListUserNodesRequest) ProtoReflect ¶
func (x *ListUserNodesRequest) ProtoReflect() protoreflect.Message
func (*ListUserNodesRequest) Reset ¶
func (x *ListUserNodesRequest) Reset()
func (*ListUserNodesRequest) String ¶
func (x *ListUserNodesRequest) String() string
type ListUserNodesResponse ¶
type ListUserNodesResponse struct {
NodeIds []string `protobuf:"bytes,1,rep,name=node_ids,json=nodeIds,proto3" json:"node_ids,omitempty"`
// contains filtered or unexported fields
}
func (*ListUserNodesResponse) Descriptor
deprecated
func (*ListUserNodesResponse) Descriptor() ([]byte, []int)
Deprecated: Use ListUserNodesResponse.ProtoReflect.Descriptor instead.
func (*ListUserNodesResponse) GetNodeIds ¶
func (x *ListUserNodesResponse) GetNodeIds() []string
func (*ListUserNodesResponse) ProtoMessage ¶
func (*ListUserNodesResponse) ProtoMessage()
func (*ListUserNodesResponse) ProtoReflect ¶
func (x *ListUserNodesResponse) ProtoReflect() protoreflect.Message
func (*ListUserNodesResponse) Reset ¶
func (x *ListUserNodesResponse) Reset()
func (*ListUserNodesResponse) String ¶
func (x *ListUserNodesResponse) String() string
type NodeStatusChanged ¶
type NodeStatusChanged struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
Online bool `protobuf:"varint,2,opt,name=online,proto3" json:"online,omitempty"`
// contains filtered or unexported fields
}
func (*NodeStatusChanged) Descriptor
deprecated
func (*NodeStatusChanged) Descriptor() ([]byte, []int)
Deprecated: Use NodeStatusChanged.ProtoReflect.Descriptor instead.
func (*NodeStatusChanged) GetNodeId ¶
func (x *NodeStatusChanged) GetNodeId() string
func (*NodeStatusChanged) GetOnline ¶
func (x *NodeStatusChanged) GetOnline() bool
func (*NodeStatusChanged) ProtoMessage ¶
func (*NodeStatusChanged) ProtoMessage()
func (*NodeStatusChanged) ProtoReflect ¶
func (x *NodeStatusChanged) ProtoReflect() protoreflect.Message
func (*NodeStatusChanged) Reset ¶
func (x *NodeStatusChanged) Reset()
func (*NodeStatusChanged) String ¶
func (x *NodeStatusChanged) String() string
type Notification ¶
type Notification struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Title string `protobuf:"bytes,2,opt,name=title,proto3" json:"title,omitempty"`
Body string `protobuf:"bytes,3,opt,name=body,proto3" json:"body,omitempty"`
// contains filtered or unexported fields
}
func (*Notification) Descriptor
deprecated
func (*Notification) Descriptor() ([]byte, []int)
Deprecated: Use Notification.ProtoReflect.Descriptor instead.
func (*Notification) GetBody ¶
func (x *Notification) GetBody() string
func (*Notification) GetId ¶
func (x *Notification) GetId() string
func (*Notification) GetTitle ¶
func (x *Notification) GetTitle() string
func (*Notification) ProtoMessage ¶
func (*Notification) ProtoMessage()
func (*Notification) ProtoReflect ¶
func (x *Notification) ProtoReflect() protoreflect.Message
func (*Notification) Reset ¶
func (x *Notification) Reset()
func (*Notification) String ¶
func (x *Notification) String() string
type Service ¶
type Service struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Url string `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
NodeId string `protobuf:"bytes,4,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
CreatedAt *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
UpdatedAt *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
// contains filtered or unexported fields
}
func (*Service) Descriptor
deprecated
func (*Service) GetCreatedAt ¶
func (x *Service) GetCreatedAt() *timestamppb.Timestamp
func (*Service) GetUpdatedAt ¶
func (x *Service) GetUpdatedAt() *timestamppb.Timestamp
func (*Service) ProtoMessage ¶
func (*Service) ProtoMessage()
func (*Service) ProtoReflect ¶
func (x *Service) ProtoReflect() protoreflect.Message
type StorageItem ¶
type StorageItem struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
ServiceId string `protobuf:"bytes,2,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
Type string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"` // Type of storage item (e.g., "frame", "clip")
Size int64 `protobuf:"varint,4,opt,name=size,proto3" json:"size,omitempty"`
Timestamp *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
Metadata string `protobuf:"bytes,6,opt,name=metadata,proto3" json:"metadata,omitempty"` // Raw JSON metadata
// contains filtered or unexported fields
}
StorageItem metadata
func (*StorageItem) Descriptor
deprecated
func (*StorageItem) Descriptor() ([]byte, []int)
Deprecated: Use StorageItem.ProtoReflect.Descriptor instead.
func (*StorageItem) GetId ¶
func (x *StorageItem) GetId() string
func (*StorageItem) GetMetadata ¶
func (x *StorageItem) GetMetadata() string
func (*StorageItem) GetServiceId ¶
func (x *StorageItem) GetServiceId() string
func (*StorageItem) GetSize ¶
func (x *StorageItem) GetSize() int64
func (*StorageItem) GetTimestamp ¶
func (x *StorageItem) GetTimestamp() *timestamppb.Timestamp
func (*StorageItem) GetType ¶
func (x *StorageItem) GetType() string
func (*StorageItem) ProtoMessage ¶
func (*StorageItem) ProtoMessage()
func (*StorageItem) ProtoReflect ¶
func (x *StorageItem) ProtoReflect() protoreflect.Message
func (*StorageItem) Reset ¶
func (x *StorageItem) Reset()
func (*StorageItem) String ¶
func (x *StorageItem) String() string
type StreamEventsByNodeIdRequest ¶
type StreamEventsByNodeIdRequest struct {
NodeId string `protobuf:"bytes,1,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"` // Required: filter events by node
ServiceId string `protobuf:"bytes,2,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"` // Optional: filter by specific service
SinceTimestamp int64 `protobuf:"varint,3,opt,name=since_timestamp,json=sinceTimestamp,proto3" json:"since_timestamp,omitempty"` // Optional: Unix nanoseconds (for replay)
// contains filtered or unexported fields
}
func (*StreamEventsByNodeIdRequest) Descriptor
deprecated
func (*StreamEventsByNodeIdRequest) Descriptor() ([]byte, []int)
Deprecated: Use StreamEventsByNodeIdRequest.ProtoReflect.Descriptor instead.
func (*StreamEventsByNodeIdRequest) GetNodeId ¶
func (x *StreamEventsByNodeIdRequest) GetNodeId() string
func (*StreamEventsByNodeIdRequest) GetServiceId ¶
func (x *StreamEventsByNodeIdRequest) GetServiceId() string
func (*StreamEventsByNodeIdRequest) GetSinceTimestamp ¶
func (x *StreamEventsByNodeIdRequest) GetSinceTimestamp() int64
func (*StreamEventsByNodeIdRequest) ProtoMessage ¶
func (*StreamEventsByNodeIdRequest) ProtoMessage()
func (*StreamEventsByNodeIdRequest) ProtoReflect ¶
func (x *StreamEventsByNodeIdRequest) ProtoReflect() protoreflect.Message
func (*StreamEventsByNodeIdRequest) Reset ¶
func (x *StreamEventsByNodeIdRequest) Reset()
func (*StreamEventsByNodeIdRequest) String ¶
func (x *StreamEventsByNodeIdRequest) String() string
type StreamEventsByNodeIdResponse ¶
type StreamEventsByNodeIdResponse struct {
// Types that are valid to be assigned to Payload:
//
// *StreamEventsByNodeIdResponse_Event
// *StreamEventsByNodeIdResponse_Heartbeat
Payload isStreamEventsByNodeIdResponse_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*StreamEventsByNodeIdResponse) Descriptor
deprecated
func (*StreamEventsByNodeIdResponse) Descriptor() ([]byte, []int)
Deprecated: Use StreamEventsByNodeIdResponse.ProtoReflect.Descriptor instead.
func (*StreamEventsByNodeIdResponse) GetEvent ¶
func (x *StreamEventsByNodeIdResponse) GetEvent() *Event
func (*StreamEventsByNodeIdResponse) GetHeartbeat ¶
func (x *StreamEventsByNodeIdResponse) GetHeartbeat() string
func (*StreamEventsByNodeIdResponse) GetPayload ¶
func (x *StreamEventsByNodeIdResponse) GetPayload() isStreamEventsByNodeIdResponse_Payload
func (*StreamEventsByNodeIdResponse) ProtoMessage ¶
func (*StreamEventsByNodeIdResponse) ProtoMessage()
func (*StreamEventsByNodeIdResponse) ProtoReflect ¶
func (x *StreamEventsByNodeIdResponse) ProtoReflect() protoreflect.Message
func (*StreamEventsByNodeIdResponse) Reset ¶
func (x *StreamEventsByNodeIdResponse) Reset()
func (*StreamEventsByNodeIdResponse) String ¶
func (x *StreamEventsByNodeIdResponse) String() string
type StreamEventsByNodeIdResponse_Event ¶
type StreamEventsByNodeIdResponse_Event struct {
Event *Event `protobuf:"bytes,1,opt,name=event,proto3,oneof"` // New event
}
type StreamEventsByNodeIdResponse_Heartbeat ¶
type StreamEventsByNodeIdResponse_Heartbeat struct {
Heartbeat string `protobuf:"bytes,2,opt,name=heartbeat,proto3,oneof"` // Keep-alive (every 30s)
}
type StreamLiveUpdatesRequest ¶
type StreamLiveUpdatesRequest struct {
NodeIds []string `protobuf:"bytes,1,rep,name=node_ids,json=nodeIds,proto3" json:"node_ids,omitempty"`
// contains filtered or unexported fields
}
func (*StreamLiveUpdatesRequest) Descriptor
deprecated
func (*StreamLiveUpdatesRequest) Descriptor() ([]byte, []int)
Deprecated: Use StreamLiveUpdatesRequest.ProtoReflect.Descriptor instead.
func (*StreamLiveUpdatesRequest) GetNodeIds ¶
func (x *StreamLiveUpdatesRequest) GetNodeIds() []string
func (*StreamLiveUpdatesRequest) ProtoMessage ¶
func (*StreamLiveUpdatesRequest) ProtoMessage()
func (*StreamLiveUpdatesRequest) ProtoReflect ¶
func (x *StreamLiveUpdatesRequest) ProtoReflect() protoreflect.Message
func (*StreamLiveUpdatesRequest) Reset ¶
func (x *StreamLiveUpdatesRequest) Reset()
func (*StreamLiveUpdatesRequest) String ¶
func (x *StreamLiveUpdatesRequest) String() string
type StreamLiveUpdatesResponse ¶
type StreamLiveUpdatesResponse struct {
// Types that are valid to be assigned to Payload:
//
// *StreamLiveUpdatesResponse_NodeStatusChanged
// *StreamLiveUpdatesResponse_Notification
// *StreamLiveUpdatesResponse_Heartbeat
Payload isStreamLiveUpdatesResponse_Payload `protobuf_oneof:"payload"`
// contains filtered or unexported fields
}
func (*StreamLiveUpdatesResponse) Descriptor
deprecated
func (*StreamLiveUpdatesResponse) Descriptor() ([]byte, []int)
Deprecated: Use StreamLiveUpdatesResponse.ProtoReflect.Descriptor instead.
func (*StreamLiveUpdatesResponse) GetHeartbeat ¶
func (x *StreamLiveUpdatesResponse) GetHeartbeat() string
func (*StreamLiveUpdatesResponse) GetNodeStatusChanged ¶
func (x *StreamLiveUpdatesResponse) GetNodeStatusChanged() *NodeStatusChanged
func (*StreamLiveUpdatesResponse) GetNotification ¶
func (x *StreamLiveUpdatesResponse) GetNotification() *Notification
func (*StreamLiveUpdatesResponse) GetPayload ¶
func (x *StreamLiveUpdatesResponse) GetPayload() isStreamLiveUpdatesResponse_Payload
func (*StreamLiveUpdatesResponse) ProtoMessage ¶
func (*StreamLiveUpdatesResponse) ProtoMessage()
func (*StreamLiveUpdatesResponse) ProtoReflect ¶
func (x *StreamLiveUpdatesResponse) ProtoReflect() protoreflect.Message
func (*StreamLiveUpdatesResponse) Reset ¶
func (x *StreamLiveUpdatesResponse) Reset()
func (*StreamLiveUpdatesResponse) String ¶
func (x *StreamLiveUpdatesResponse) String() string
type StreamLiveUpdatesResponse_Heartbeat ¶
type StreamLiveUpdatesResponse_Heartbeat struct {
Heartbeat string `protobuf:"bytes,3,opt,name=heartbeat,proto3,oneof"`
}
type StreamLiveUpdatesResponse_NodeStatusChanged ¶
type StreamLiveUpdatesResponse_NodeStatusChanged struct {
NodeStatusChanged *NodeStatusChanged `protobuf:"bytes,1,opt,name=node_status_changed,json=nodeStatusChanged,proto3,oneof"`
}
type StreamLiveUpdatesResponse_Notification ¶
type StreamLiveUpdatesResponse_Notification struct {
Notification *Notification `protobuf:"bytes,2,opt,name=notification,proto3,oneof"`
}
type UpdateServiceRequest ¶
type UpdateServiceRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Url string `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateServiceRequest) Descriptor
deprecated
func (*UpdateServiceRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateServiceRequest.ProtoReflect.Descriptor instead.
func (*UpdateServiceRequest) GetId ¶
func (x *UpdateServiceRequest) GetId() string
func (*UpdateServiceRequest) GetName ¶
func (x *UpdateServiceRequest) GetName() string
func (*UpdateServiceRequest) GetUrl ¶
func (x *UpdateServiceRequest) GetUrl() string
func (*UpdateServiceRequest) ProtoMessage ¶
func (*UpdateServiceRequest) ProtoMessage()
func (*UpdateServiceRequest) ProtoReflect ¶
func (x *UpdateServiceRequest) ProtoReflect() protoreflect.Message
func (*UpdateServiceRequest) Reset ¶
func (x *UpdateServiceRequest) Reset()
func (*UpdateServiceRequest) String ¶
func (x *UpdateServiceRequest) String() string
type UpdateServiceResponse ¶
type UpdateServiceResponse struct {
Service *Service `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
// contains filtered or unexported fields
}
func (*UpdateServiceResponse) Descriptor
deprecated
func (*UpdateServiceResponse) Descriptor() ([]byte, []int)
Deprecated: Use UpdateServiceResponse.ProtoReflect.Descriptor instead.
func (*UpdateServiceResponse) GetService ¶
func (x *UpdateServiceResponse) GetService() *Service
func (*UpdateServiceResponse) ProtoMessage ¶
func (*UpdateServiceResponse) ProtoMessage()
func (*UpdateServiceResponse) ProtoReflect ¶
func (x *UpdateServiceResponse) ProtoReflect() protoreflect.Message
func (*UpdateServiceResponse) Reset ¶
func (x *UpdateServiceResponse) Reset()
func (*UpdateServiceResponse) String ¶
func (x *UpdateServiceResponse) String() string